pub type ActionRegistry = CommandRegistry;Expand description
Action registry (v1).
v1 strategy (ADR 0307): action metadata is stored in the existing command registry.
Aliased Type
pub struct ActionRegistry { /* private fields */ }pub type ActionRegistry = CommandRegistry;Action registry (v1).
v1 strategy (ADR 0307): action metadata is stored in the existing command registry.
pub struct ActionRegistry { /* private fields */ }