WindowPendingActionPayloadService

Struct WindowPendingActionPayloadService 

pub struct WindowPendingActionPayloadService { /* private fields */ }
Window-scoped, tick-local payload store for parameterized actions (v2 prototype).

This is intentionally best-effort and transient:

  • callers should record a payload immediately before dispatching an ActionId,
  • handlers should consume the payload at dispatch time (or treat missing payload as not handled),
  • entries expire after a small tick TTL.

See ADR 0312.

Implementations

Source

impl WindowPendingActionPayloadService

pub fn record( &mut self, window: AppWindowId, tick_id: TickId, action: ActionId, payload: Box<dyn Any + Send + Sync>, )

pub fn consume( &mut self, window: AppWindowId, tick_id: TickId, action: &ActionId, ) -> Option<Box<dyn Any + Send + Sync>>