pub struct FontCatalogMetadata {
pub entries: Vec<FontCatalogEntry>,
pub revision: u64,
}Expand description
Best-effort catalog metadata (entries + revision).
The revision is expected to be monotonic and should generally match FontCatalog.revision when
both are set by the runner.
Fields
entries: Vec<FontCatalogEntry>revision: u64Monotonic revision that increments when the effective entry list changes.