pub struct TextFontStackKey(pub u64);Expand description
Stable key representing the current effective text font stack / fallback configuration.
Runners should update this whenever the renderer text backend changes in a way that can affect shaping/metrics: font family overrides, user font loading, web font injection, etc.
Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for TextFontStackKey
impl Clone for TextFontStackKey
Sourcefn clone(&self) -> TextFontStackKey
fn clone(&self) -> TextFontStackKey
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TextFontStackKey
impl Debug for TextFontStackKey
Sourceimpl Default for TextFontStackKey
impl Default for TextFontStackKey
Sourcefn default() -> TextFontStackKey
fn default() -> TextFontStackKey
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TextFontStackKey
impl<'de> Deserialize<'de> for TextFontStackKey
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for TextFontStackKey
impl PartialEq for TextFontStackKey
Sourceimpl Serialize for TextFontStackKey
impl Serialize for TextFontStackKey
impl Copy for TextFontStackKey
impl Eq for TextFontStackKey
impl StructuralPartialEq for TextFontStackKey