pub struct SequenceMatch {
pub exact: Option<Option<CommandId>>,
pub has_continuation: bool,
}Fields
exact: Option<Option<CommandId>>Some(Some(cmd)) if an exact binding exists and is bound, Some(None) if explicitly unbound,
and None if no exact binding exists under the provided context.
has_continuation: boolTrue if any longer binding exists that starts with the provided sequence under the same context.