ItemSelectorTyped

Enum ItemSelectorTyped 

pub enum ItemSelectorTyped {
    Submenu {
        title: String,
    },
    Label {
        title: String,
    },
}

Variants



Submenu

Select the first submenu item with the given title.

Note: if multiple submenus share the same title, prefer using an index anchor instead.

Fields

title: String


Label

Select the first label item with the given title.

Note: if multiple labels share the same title, prefer using an index anchor instead.

Fields

title: String