Module model

Module model 

Structs

Model
A reference-counted handle to a typed model stored in a ModelStore.
ModelChangedDebugInfo
ModelCreatedDebugInfo
ModelCx
Context passed to model update closures.
ModelId
Opaque identifier for a model entry stored in a ModelStore.
ModelStore
Main-thread-only storage for typed models.
WeakModel

Enums

ModelUpdateError

Traits

ModelHost
Host surface required to read and update models stored in a ModelStore.