RunnerAccessibilitySnapshot

Struct RunnerAccessibilitySnapshot 

pub struct RunnerAccessibilitySnapshot {
    pub activation_requests: u64,
    pub last_activation_unix_ms: Option<u64>,
    pub last_activation_frame_id: Option<FrameId>,
}
Diagnostics store for runner accessibility activation events.

This is intended as a lightweight evidence anchor that the AccessKit platform adapter has been activated by the OS accessibility stack (e.g. macOS AX / VoiceOver), rather than only producing an internal semantics tree.

Fields

activation_requests: u64last_activation_unix_ms: Option<u64>last_activation_frame_id: Option<FrameId>