pub struct RunnerSurfaceLifecycleSnapshot {
pub can_create_surfaces_calls: u64,
pub destroy_surfaces_calls: u64,
pub last_can_create_surfaces_unix_ms: Option<u64>,
pub last_destroy_surfaces_unix_ms: Option<u64>,
pub surfaces_available: bool,
}Expand description
Diagnostics store for runner surface lifecycle transitions.
This is intended to help mobile bring-up verify that winit lifecycle hooks are firing and that surfaces are dropped/recreated as expected on background/foreground transitions.
Fields
can_create_surfaces_calls: u64destroy_surfaces_calls: u64last_can_create_surfaces_unix_ms: Option<u64>last_destroy_surfaces_unix_ms: Option<u64>surfaces_available: boolTrait Implementations
Sourceimpl Clone for RunnerSurfaceLifecycleSnapshot
impl Clone for RunnerSurfaceLifecycleSnapshot
Sourcefn clone(&self) -> RunnerSurfaceLifecycleSnapshot
fn clone(&self) -> RunnerSurfaceLifecycleSnapshot
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RunnerSurfaceLifecycleSnapshot
impl Default for RunnerSurfaceLifecycleSnapshot
Sourcefn default() -> RunnerSurfaceLifecycleSnapshot
fn default() -> RunnerSurfaceLifecycleSnapshot
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for RunnerSurfaceLifecycleSnapshot
impl PartialEq for RunnerSurfaceLifecycleSnapshot
Sourcefn eq(&self, other: &RunnerSurfaceLifecycleSnapshot) -> bool
fn eq(&self, other: &RunnerSurfaceLifecycleSnapshot) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for RunnerSurfaceLifecycleSnapshot
impl Eq for RunnerSurfaceLifecycleSnapshot
impl StructuralPartialEq for RunnerSurfaceLifecycleSnapshot