RunnerWindowAppearanceV1

Enum RunnerWindowAppearanceV1 

pub enum RunnerWindowAppearanceV1 {
    Opaque,
    CompositedNoBackdrop,
    CompositedBackdrop,
}

Variants



Opaque

The OS window is not composited with alpha.



CompositedNoBackdrop

The OS window surface is composited with alpha, but no OS backdrop material is enabled.



CompositedBackdrop

The OS window surface is composited with alpha and an OS backdrop material is enabled.