FontFamilyDefaultsPolicy

Enum FontFamilyDefaultsPolicy 

pub enum FontFamilyDefaultsPolicy {
    None,
    FillIfEmpty,
    FillIfEmptyFromCatalogPrefix {
        max: usize,
    },
    FillIfEmptyWithCuratedCandidates,
}

Variants



None



FillIfEmpty



FillIfEmptyFromCatalogPrefix

If any UI family list is empty, seed it from the head of the current font catalog.

This is primarily intended for Web/WASM bootstrap, where system font discovery is not available and we need a deterministic, minimal fallback without exploding settings to “all fonts”.

Fields

max: usize


FillIfEmptyWithCuratedCandidates

If any UI family list is empty, seed it with a small curated list of common UI families.

This is primarily intended for Web/WASM bootstrap.