MenuItem

Enum MenuItem 

pub enum MenuItem {
    Command {
        command: CommandId,
        when: Option<WhenExpr>,
        toggle: Option<MenuItemToggle>,
    },
    Label {
        title: Arc<str>,
    },
    Separator,
    Submenu {
        title: Arc<str>,
        when: Option<WhenExpr>,
        items: Vec<MenuItem>,
    },
    SystemMenu {
        title: Arc<str>,
        menu_type: SystemMenuType,
    },
}

Variants



Command

Fields

command: CommandId


Label

A non-interactive, disabled menu entry with a custom label.

This is intended for placeholder and dynamic menu content where a CommandId is not available (yet). Menu surfaces should render this as disabled text.

Fields

title: Arc<str>


Separator



Submenu

Fields

title: Arc<str>
items: Vec<MenuItem>


SystemMenu

A menu managed by the OS (e.g. the macOS Services menu).

In-window menu surfaces should ignore or render a disabled placeholder for these entries.

Fields

title: Arc<str>
menu_type: SystemMenuType