Structs
- Model
- A reference-counted handle to a typed model stored in a
ModelStore. - Model
Changed Debug Info - Model
Created Debug Info - ModelCx
- Context passed to model update closures.
- ModelId
- Opaque identifier for a model entry stored in a
ModelStore. - Model
Store - Main-thread-only storage for typed models.
- Weak
Model
Enums
Traits
- Model
Host - Host surface required to read and update models stored in a
ModelStore.