pub struct RunnerWindowStyleEffectiveSnapshotV1 {Show 17 fields
pub decorations: WindowDecorationsRequest,
pub resizable: bool,
pub surface_composited_alpha: bool,
pub surface_composited_alpha_source: RunnerWindowCompositedAlphaSourceV1,
pub visual_transparent: bool,
pub appearance: RunnerWindowAppearanceV1,
pub background_material: WindowBackgroundMaterialRequest,
pub hit_test: WindowHitTestRequestV1,
pub hit_test_requested: Option<WindowHitTestRequestV1>,
pub hit_test_regions_signature: Option<String>,
pub hit_test_regions_fingerprint64: Option<u64>,
pub hit_test_regions_requested_fingerprint64: Option<u64>,
pub hit_test_source: RunnerWindowHitTestSourceV1,
pub hit_test_clamp_reason: RunnerWindowHitTestClampReasonV1,
pub taskbar: TaskbarVisibility,
pub activation: ActivationPolicy,
pub z_level: WindowZLevel,
}Fields
decorations: WindowDecorationsRequestresizable: boolsurface_composited_alpha: boolWhether the OS window surface is composited with alpha (create-time; may be sticky).
surface_composited_alpha_source: RunnerWindowCompositedAlphaSourceV1Why the surface is (or is not) composited.
visual_transparent: boolWhether the runner will preserve alpha by default (clear alpha = 0) for this window.
This is a visual policy decision used by the runner+renderer. It is intentionally
separated from surface_composited_alpha to avoid conflating “window can be composited”
with “window is visually transparent”.
appearance: RunnerWindowAppearanceV1A derived, user-facing summary of window background appearance facets.
background_material: WindowBackgroundMaterialRequesthit_test: WindowHitTestRequestV1Effective window hit test policy (pointer passthrough).
hit_test_requested: Option<WindowHitTestRequestV1>Last requested hit test policy (pre-clamp), if any.
hit_test_regions_signature: Option<String>Stable signature string for effective PassthroughRegions, if any.
hit_test_regions_fingerprint64: Option<u64>Stable FNV-1a 64-bit fingerprint of hit_test_regions_signature, if any.
hit_test_regions_requested_fingerprint64: Option<u64>Stable FNV-1a 64-bit fingerprint of requested PassthroughRegions, if any.
hit_test_source: RunnerWindowHitTestSourceV1hit_test_clamp_reason: RunnerWindowHitTestClampReasonV1taskbar: TaskbarVisibilityactivation: ActivationPolicyz_level: WindowZLevelTrait Implementations
Sourceimpl Clone for RunnerWindowStyleEffectiveSnapshotV1
impl Clone for RunnerWindowStyleEffectiveSnapshotV1
Sourcefn clone(&self) -> RunnerWindowStyleEffectiveSnapshotV1
fn clone(&self) -> RunnerWindowStyleEffectiveSnapshotV1
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl PartialEq for RunnerWindowStyleEffectiveSnapshotV1
impl PartialEq for RunnerWindowStyleEffectiveSnapshotV1
Sourcefn eq(&self, other: &RunnerWindowStyleEffectiveSnapshotV1) -> bool
fn eq(&self, other: &RunnerWindowStyleEffectiveSnapshotV1) -> bool
self and other values to be equal, and is used by ==.